@@ -1,7 +1,7 @@
 use strict;
 use warnings FATAL => 'all';
 
-use Test::More tests => 20;
+use Test::More tests => 21;
 
 use_ok('CGI::SSI');
 
@@ -206,6 +206,13 @@ use_ok('CGI::SSI');
     ok($html eq "FOO",'inherit 2');
 }
 
+# DATE_LOCAL/DATE_GMT with config{timefmt}
+{
+    my $ssi = new CGI::SSI (timefmt => '%Y');
+    ok($ssi->echo('DATE_LOCAL') =~ /^\d{4}$/,'config{timefmt}');
+}
+
+
 # autotie ?
 # tie by hand
 
